Citation
--------

@Authors:

Sébastien Ravel (CIRAD).

Thanks
======

Thanks to Ndomassi Tando (i-Trop IRD) for his administration support.

The authors acknowledge the IRD i-Trop HPC (South Green Platform) from IRD Montpellier for providing HPC resources that contributed to this work. https://bioinfo.ird.fr/ - http://www.southgreen.fr

Thanks to all collaborator of `CulebrONT <https://culebront-pipeline.readthedocs.io/en/latest/>`_ tool which help to developed  `Snakecdysis <https://snakecdysis.readthedocs.io/en/latest/>`_ and docs



License
-------

Licenced under CeCill-C (http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html) and GPLv3
Intellectual property belongs to IRD and authors.
